/**********************************************************************
** $Id: qcombo.h,v 1.21 1996/08/27 19:07:03 paul Exp $
**
** Definition of QComboBox class
**
** Author  : Eirik Eng
** Created : 950426
**
** Copyright (C) 1992-1996 Troll Tech AS.  All rights reserved.
**
** This file is part of the non-commercial distribution of Qt 0.99
** see the file LICENSE included in the distribution for the usage
** and distribution terms, or http://www.troll.no/qt/license.html.
**
** (This file differs from the commercial version of Qt only by this comment.)
**
*****************************************************************************/

#ifndef QCOMBO_H
#define QCOMBO_H

#include "qwidget.h"


struct QComboData;
class  QStrList;


class QComboBox : public QWidget
{
    Q_OBJECT
public:
    QComboBox( QWidget *parent=0, const char *name=0 );
   ~QComboBox();

    int		count() const;

    void	insertStrList( const QStrList *, int index=-1 );
    void	insertStrList( const char **, int numStrings=-1, int index=-1);


    void	insertItem( const char *text, int index=-1 );
    void	insertItem( const QPixmap &pixmap, int index=-1 );

    void	removeItem( int index );
    void	clear();

    const char *text( int index ) const;
    QPixmap    *pixmap( int index ) const;

    void	changeItem( const char *text, int index );
    void	changeItem( const QPixmap &pixmap, int index );

    int		currentItem()	const;
    void	setCurrentItem( int index );

    bool	autoResize()	const;
    void	setAutoResize( bool );
    QSize	sizeHint() const;

    void	setBackgroundColor( const QColor & );
    void	setPalette( const QPalette & );
    void	setFont( const QFont & );

signals:
    void	activated( int index );
    void	highlighted( int index );

private slots:
    void	internalActivate( int );
    void	internalHighlight( int );

protected:
    void	paintEvent( QPaintEvent * );
    void	mousePressEvent( QMouseEvent * );
    void	mouseMoveEvent( QMouseEvent * );
    void	mouseReleaseEvent( QMouseEvent * );
    void	mouseDoubleClickEvent( QMouseEvent * );
    void	keyPressEvent( QKeyEvent *e );

    void	popup();

private:
    void	reIndex();
    void	currentChanged();

    QComboData	*d;

#if defined(OBSOLETE)
public:
    void	setStrList( const QStrList *list );
    void	setStrList( const char **strings, int numStrings=-1 );
    const char *string( int index ) const;
#endif


private:	// Disabled copy constructor and operator=
    QComboBox( const QComboBox & ) {}
    QComboBox &operator=( const QComboBox & ) { return *this; }
};

#if defined(OBSOLETE)
inline void QComboBox::setStrList( const QStrList *list )
{
    qObsolete("QComboBox","setStrList","insertStrList (probably)");
    clear(); 
    insertStrList(list,0); 
}
inline void QComboBox::setStrList( const char **strings, int numStrings )
{ 
    qObsolete("QComboBox","setStrList","insertStrList (probably)");
    clear(); 	
    insertStrList(strings,numStrings,0); 
}
inline const char *QComboBox::string( int index ) const  
{ 
    qObsolete("QComboBox","string","text");
    return text(index); 
}
#endif


#endif // QCOMBOBOX_H
